@@ -1,15 +1,12 @@
 package Search::Query::Field;
-use Moo;
+use strict;
+use warnings;
 use Carp;
+use base qw( Rose::ObjectX::CAF );
 
-use namespace::sweep;
+our $VERSION = '0.02';
 
-our $VERSION = '0.290_02';
-
-has 'name'      => ( is => 'rw' );
-has 'alias_for' => ( is => 'rw' );
-has 'callback'  => ( is => 'rw' );
-has 'error'     => ( is => 'rw' );
+__PACKAGE__->mk_accessors(qw( name alias_for ));
 
 =head1 NAME
 
@@ -40,21 +37,7 @@ Get/set the name of the field.
 
 Get/set the alternate names for the field. Can be a string or array ref.
 
-=head2 callback
-
-Standard attribute accessor. Expects a CODE reference.
-
-If defined on a Field object, the callback is invoked whenever a Clause
-is stringified or serialized. The CODE reference should expect 3 arguments:
-the field name, the operator and the value. It should return a serialized
-or serializable value. Example:
-
- $field->callback(sub {
-     my ($field, $op, $value) = @_;
-     return "$field $op $value";
- });
-
-=head2 validate( I<field_value> )
+=head2 validate
 
 The base method always returns true.
 
@@ -62,14 +45,6 @@ The base method always returns true.
 
 sub validate {1}
 
-=head2 error
-
-Get/set the error string for the Field object. The return value
-of this method is included by the Parser in any error message
-whenever validate() returns false.
-
-=cut
-
 1;
 
 __END__
